DidChangeWatchedFiles

Enum DidChangeWatchedFiles 

pub enum DidChangeWatchedFiles {}
The watched files notification is sent from the client to the server when the client detects changes to files and folders watched by the language client (note although the name suggest that only file events are sent it is about file system events which include folders as well). It is recommended that servers register for these file system events using the registration mechanism. In former implementations clients pushed file events without the server actively asking for it.