DocumentDiagnosticRequest

Enum DocumentDiagnosticRequest 

pub enum DocumentDiagnosticRequest {}
The text document diagnostic request is sent from the client to the server to ask the server to compute the diagnostics for a given document. As with other pull requests the server is asked to compute the diagnostics for the currently synced version of the document.